XK_Hangul: int
XK_Hangul_Start: int
XK_Hangul_End: int
XK_Hangul_Hanja: int
XK_Hangul_Jamo: int
XK_Hangul_Romaja: int
XK_Hangul_Codeinput: int
XK_Hangul_Jeonja: int
XK_Hangul_Banja: int
XK_Hangul_PreHanja: int
XK_Hangul_PostHanja: int
XK_Hangul_SingleCandidate: int
XK_Hangul_MultipleCandidate: int
XK_Hangul_PreviousCandidate: int
XK_Hangul_Special: int
XK_Hangul_switch: int
XK_Hangul_Kiyeog: int
XK_Hangul_SsangKiyeog: int
XK_Hangul_KiyeogSios: int
XK_Hangul_Nieun: int
XK_Hangul_NieunJieuj: int
XK_Hangul_NieunHieuh: int
XK_Hangul_Dikeud: int
XK_Hangul_SsangDikeud: int
XK_Hangul_Rieul: int
XK_Hangul_RieulKiyeog: int
XK_Hangul_RieulMieum: int
XK_Hangul_RieulPieub: int
XK_Hangul_RieulSios: int
XK_Hangul_RieulTieut: int
XK_Hangul_RieulPhieuf: int
XK_Hangul_RieulHieuh: int
XK_Hangul_Mieum: int
XK_Hangul_Pieub: int
XK_Hangul_SsangPieub: int
XK_Hangul_PieubSios: int
XK_Hangul_Sios: int
XK_Hangul_SsangSios: int
XK_Hangul_Ieung: int
XK_Hangul_Jieuj: int
XK_Hangul_SsangJieuj: int
XK_Hangul_Cieuc: int
XK_Hangul_Khieuq: int
XK_Hangul_Tieut: int
XK_Hangul_Phieuf: int
XK_Hangul_Hieuh: int
XK_Hangul_A: int
XK_Hangul_AE: int
XK_Hangul_YA: int
XK_Hangul_YAE: int
XK_Hangul_EO: int
XK_Hangul_E: int
XK_Hangul_YEO: int
XK_Hangul_YE: int
XK_Hangul_O: int
XK_Hangul_WA: int
XK_Hangul_WAE: int
XK_Hangul_OE: int
XK_Hangul_YO: int
XK_Hangul_U: int
XK_Hangul_WEO: int
XK_Hangul_WE: int
XK_Hangul_WI: int
XK_Hangul_YU: int
XK_Hangul_EU: int
XK_Hangul_YI: int
XK_Hangul_I: int
XK_Hangul_J_Kiyeog: int
XK_Hangul_J_SsangKiyeog: int
XK_Hangul_J_KiyeogSios: int
XK_Hangul_J_Nieun: int
XK_Hangul_J_NieunJieuj: int
XK_Hangul_J_NieunHieuh: int
XK_Hangul_J_Dikeud: int
XK_Hangul_J_Rieul: int
XK_Hangul_J_RieulKiyeog: int
XK_Hangul_J_RieulMieum: int
XK_Hangul_J_RieulPieub: int
XK_Hangul_J_RieulSios: int
XK_Hangul_J_RieulTieut: int
XK_Hangul_J_RieulPhieuf: int
XK_Hangul_J_RieulHieuh: int
XK_Hangul_J_Mieum: int
XK_Hangul_J_Pieub: int
XK_Hangul_J_PieubSios: int
XK_Hangul_J_Sios: int
XK_Hangul_J_SsangSios: int
XK_Hangul_J_Ieung: int
XK_Hangul_J_Jieuj: int
XK_Hangul_J_Cieuc: int
XK_Hangul_J_Khieuq: int
XK_Hangul_J_Tieut: int
XK_Hangul_J_Phieuf: int
XK_Hangul_J_Hieuh: int
XK_Hangul_RieulYeorinHieuh: int
XK_Hangul_SunkyeongeumMieum: int
XK_Hangul_SunkyeongeumPieub: int
XK_Hangul_PanSios: int
XK_Hangul_KkogjiDalrinIeung: int
XK_Hangul_SunkyeongeumPhieuf: int
XK_Hangul_YeorinHieuh: int
XK_Hangul_AraeA: int
XK_Hangul_AraeAE: int
XK_Hangul_J_PanSios: int
XK_Hangul_J_KkogjiDalrinIeung: int
XK_Hangul_J_YeorinHieuh: int
XK_Korean_Won: int
