XK_overline: int
XK_kana_fullstop: int
XK_kana_openingbracket: int
XK_kana_closingbracket: int
XK_kana_comma: int
XK_kana_conjunctive: int
XK_kana_middledot: int
XK_kana_WO: int
XK_kana_a: int
XK_kana_i: int
XK_kana_u: int
XK_kana_e: int
XK_kana_o: int
XK_kana_ya: int
XK_kana_yu: int
XK_kana_yo: int
XK_kana_tsu: int
XK_kana_tu: int
XK_prolongedsound: int
XK_kana_A: int
XK_kana_I: int
XK_kana_U: int
XK_kana_E: int
XK_kana_O: int
XK_kana_KA: int
XK_kana_KI: int
XK_kana_KU: int
XK_kana_KE: int
XK_kana_KO: int
XK_kana_SA: int
XK_kana_SHI: int
XK_kana_SU: int
XK_kana_SE: int
XK_kana_SO: int
XK_kana_TA: int
XK_kana_CHI: int
XK_kana_TI: int
XK_kana_TSU: int
XK_kana_TU: int
XK_kana_TE: int
XK_kana_TO: int
XK_kana_NA: int
XK_kana_NI: int
XK_kana_NU: int
XK_kana_NE: int
XK_kana_NO: int
XK_kana_HA: int
XK_kana_HI: int
XK_kana_FU: int
XK_kana_HU: int
XK_kana_HE: int
XK_kana_HO: int
XK_kana_MA: int
XK_kana_MI: int
XK_kana_MU: int
XK_kana_ME: int
XK_kana_MO: int
XK_kana_YA: int
XK_kana_YU: int
XK_kana_YO: int
XK_kana_RA: int
XK_kana_RI: int
XK_kana_RU: int
XK_kana_RE: int
XK_kana_RO: int
XK_kana_WA: int
XK_kana_N: int
XK_voicedsound: int
XK_semivoicedsound: int
XK_kana_switch: int
