XK_ISO_Lock: int
XK_ISO_Level2_Latch: int
XK_ISO_Level3_Shift: int
XK_ISO_Level3_Latch: int
XK_ISO_Level3_Lock: int
XK_ISO_Group_Shift: int
XK_ISO_Group_Latch: int
XK_ISO_Group_Lock: int
XK_ISO_Next_Group: int
XK_ISO_Next_Group_Lock: int
XK_ISO_Prev_Group: int
XK_ISO_Prev_Group_Lock: int
XK_ISO_First_Group: int
XK_ISO_First_Group_Lock: int
XK_ISO_Last_Group: int
XK_ISO_Last_Group_Lock: int
XK_ISO_Left_Tab: int
XK_ISO_Move_Line_Up: int
XK_ISO_Move_Line_Down: int
XK_ISO_Partial_Line_Up: int
XK_ISO_Partial_Line_Down: int
XK_ISO_Partial_Space_Left: int
XK_ISO_Partial_Space_Right: int
XK_ISO_Set_Margin_Left: int
XK_ISO_Set_Margin_Right: int
XK_ISO_Release_Margin_Left: int
XK_ISO_Release_Margin_Right: int
XK_ISO_Release_Both_Margins: int
XK_ISO_Fast_Cursor_Left: int
XK_ISO_Fast_Cursor_Right: int
XK_ISO_Fast_Cursor_Up: int
XK_ISO_Fast_Cursor_Down: int
XK_ISO_Continuous_Underline: int
XK_ISO_Discontinuous_Underline: int
XK_ISO_Emphasize: int
XK_ISO_Center_Object: int
XK_ISO_Enter: int
XK_dead_grave: int
XK_dead_acute: int
XK_dead_circumflex: int
XK_dead_tilde: int
XK_dead_macron: int
XK_dead_breve: int
XK_dead_abovedot: int
XK_dead_diaeresis: int
XK_dead_abovering: int
XK_dead_doubleacute: int
XK_dead_caron: int
XK_dead_cedilla: int
XK_dead_ogonek: int
XK_dead_iota: int
XK_dead_voiced_sound: int
XK_dead_semivoiced_sound: int
XK_dead_belowdot: int
XK_First_Virtual_Screen: int
XK_Prev_Virtual_Screen: int
XK_Next_Virtual_Screen: int
XK_Last_Virtual_Screen: int
XK_Terminate_Server: int
XK_AccessX_Enable: int
XK_AccessX_Feedback_Enable: int
XK_RepeatKeys_Enable: int
XK_SlowKeys_Enable: int
XK_BounceKeys_Enable: int
XK_StickyKeys_Enable: int
XK_MouseKeys_Enable: int
XK_MouseKeys_Accel_Enable: int
XK_Overlay1_Enable: int
XK_Overlay2_Enable: int
XK_AudibleBell_Enable: int
XK_Pointer_Left: int
XK_Pointer_Right: int
XK_Pointer_Up: int
XK_Pointer_Down: int
XK_Pointer_UpLeft: int
XK_Pointer_UpRight: int
XK_Pointer_DownLeft: int
XK_Pointer_DownRight: int
XK_Pointer_Button_Dflt: int
XK_Pointer_Button1: int
XK_Pointer_Button2: int
XK_Pointer_Button3: int
XK_Pointer_Button4: int
XK_Pointer_Button5: int
XK_Pointer_DblClick_Dflt: int
XK_Pointer_DblClick1: int
XK_Pointer_DblClick2: int
XK_Pointer_DblClick3: int
XK_Pointer_DblClick4: int
XK_Pointer_DblClick5: int
XK_Pointer_Drag_Dflt: int
XK_Pointer_Drag1: int
XK_Pointer_Drag2: int
XK_Pointer_Drag3: int
XK_Pointer_Drag4: int
XK_Pointer_Drag5: int
XK_Pointer_EnableKeys: int
XK_Pointer_Accelerate: int
XK_Pointer_DfltBtnNext: int
XK_Pointer_DfltBtnPrev: int
