XK_BackSpace: int
XK_Tab: int
XK_Linefeed: int
XK_Clear: int
XK_Return: int
XK_Pause: int
XK_Scroll_Lock: int
XK_Sys_Req: int
XK_Escape: int
XK_Delete: int
XK_Multi_key: int
XK_SingleCandidate: int
XK_MultipleCandidate: int
XK_PreviousCandidate: int
XK_Kanji: int
XK_Muhenkan: int
XK_Henkan_Mode: int
XK_Henkan: int
XK_Romaji: int
XK_Hiragana: int
XK_Katakana: int
XK_Hiragana_Katakana: int
XK_Zenkaku: int
XK_Hankaku: int
XK_Zenkaku_Hankaku: int
XK_Touroku: int
XK_Massyo: int
XK_Kana_Lock: int
XK_Kana_Shift: int
XK_Eisu_Shift: int
XK_Eisu_toggle: int
XK_Zen_Koho: int
XK_Mae_Koho: int
XK_Home: int
XK_Left: int
XK_Up: int
XK_Right: int
XK_Down: int
XK_Prior: int
XK_Page_Up: int
XK_Next: int
XK_Page_Down: int
XK_End: int
XK_Begin: int
XK_Select: int
XK_Print: int
XK_Execute: int
XK_Insert: int
XK_Undo: int
XK_Redo: int
XK_Menu: int
XK_Find: int
XK_Cancel: int
XK_Help: int
XK_Break: int
XK_Mode_switch: int
XK_script_switch: int
XK_Num_Lock: int
XK_KP_Space: int
XK_KP_Tab: int
XK_KP_Enter: int
XK_KP_F1: int
XK_KP_F2: int
XK_KP_F3: int
XK_KP_F4: int
XK_KP_Home: int
XK_KP_Left: int
XK_KP_Up: int
XK_KP_Right: int
XK_KP_Down: int
XK_KP_Prior: int
XK_KP_Page_Up: int
XK_KP_Next: int
XK_KP_Page_Down: int
XK_KP_End: int
XK_KP_Begin: int
XK_KP_Insert: int
XK_KP_Delete: int
XK_KP_Equal: int
XK_KP_Multiply: int
XK_KP_Add: int
XK_KP_Separator: int
XK_KP_Subtract: int
XK_KP_Decimal: int
XK_KP_Divide: int
XK_KP_0: int
XK_KP_1: int
XK_KP_2: int
XK_KP_3: int
XK_KP_4: int
XK_KP_5: int
XK_KP_6: int
XK_KP_7: int
XK_KP_8: int
XK_KP_9: int
XK_F1: int
XK_F2: int
XK_F3: int
XK_F4: int
XK_F5: int
XK_F6: int
XK_F7: int
XK_F8: int
XK_F9: int
XK_F10: int
XK_F11: int
XK_L1: int
XK_F12: int
XK_L2: int
XK_F13: int
XK_L3: int
XK_F14: int
XK_L4: int
XK_F15: int
XK_L5: int
XK_F16: int
XK_L6: int
XK_F17: int
XK_L7: int
XK_F18: int
XK_L8: int
XK_F19: int
XK_L9: int
XK_F20: int
XK_L10: int
XK_F21: int
XK_R1: int
XK_F22: int
XK_R2: int
XK_F23: int
XK_R3: int
XK_F24: int
XK_R4: int
XK_F25: int
XK_R5: int
XK_F26: int
XK_R6: int
XK_F27: int
XK_R7: int
XK_F28: int
XK_R8: int
XK_F29: int
XK_R9: int
XK_F30: int
XK_R10: int
XK_F31: int
XK_R11: int
XK_F32: int
XK_R12: int
XK_F33: int
XK_R13: int
XK_F34: int
XK_R14: int
XK_F35: int
XK_R15: int
XK_Shift_L: int
XK_Shift_R: int
XK_Control_L: int
XK_Control_R: int
XK_Caps_Lock: int
XK_Shift_Lock: int
XK_Meta_L: int
XK_Meta_R: int
XK_Alt_L: int
XK_Alt_R: int
XK_Super_L: int
XK_Super_R: int
XK_Hyper_L: int
XK_Hyper_R: int
