XK_Greek_ALPHAaccent: int
XK_Greek_EPSILONaccent: int
XK_Greek_ETAaccent: int
XK_Greek_IOTAaccent: int
XK_Greek_IOTAdiaeresis: int
XK_Greek_OMICRONaccent: int
XK_Greek_UPSILONaccent: int
XK_Greek_UPSILONdieresis: int
XK_Greek_OMEGAaccent: int
XK_Greek_accentdieresis: int
XK_Greek_horizbar: int
XK_Greek_alphaaccent: int
XK_Greek_epsilonaccent: int
XK_Greek_etaaccent: int
XK_Greek_iotaaccent: int
XK_Greek_iotadieresis: int
XK_Greek_iotaaccentdieresis: int
XK_Greek_omicronaccent: int
XK_Greek_upsilonaccent: int
XK_Greek_upsilondieresis: int
XK_Greek_upsilonaccentdieresis: int
XK_Greek_omegaaccent: int
XK_Greek_ALPHA: int
XK_Greek_BETA: int
XK_Greek_GAMMA: int
XK_Greek_DELTA: int
XK_Greek_EPSILON: int
XK_Greek_ZETA: int
XK_Greek_ETA: int
XK_Greek_THETA: int
XK_Greek_IOTA: int
XK_Greek_KAPPA: int
XK_Greek_LAMDA: int
XK_Greek_LAMBDA: int
XK_Greek_MU: int
XK_Greek_NU: int
XK_Greek_XI: int
XK_Greek_OMICRON: int
XK_Greek_PI: int
XK_Greek_RHO: int
XK_Greek_SIGMA: int
XK_Greek_TAU: int
XK_Greek_UPSILON: int
XK_Greek_PHI: int
XK_Greek_CHI: int
XK_Greek_PSI: int
XK_Greek_OMEGA: int
XK_Greek_alpha: int
XK_Greek_beta: int
XK_Greek_gamma: int
XK_Greek_delta: int
XK_Greek_epsilon: int
XK_Greek_zeta: int
XK_Greek_eta: int
XK_Greek_theta: int
XK_Greek_iota: int
XK_Greek_kappa: int
XK_Greek_lamda: int
XK_Greek_lambda: int
XK_Greek_mu: int
XK_Greek_nu: int
XK_Greek_xi: int
XK_Greek_omicron: int
XK_Greek_pi: int
XK_Greek_rho: int
XK_Greek_sigma: int
XK_Greek_finalsmallsigma: int
XK_Greek_tau: int
XK_Greek_upsilon: int
XK_Greek_phi: int
XK_Greek_chi: int
XK_Greek_psi: int
XK_Greek_omega: int
XK_Greek_switch: int
