XK_Aogonek: int
XK_breve: int
XK_Lstroke: int
XK_Lcaron: int
XK_Sacute: int
XK_Scaron: int
XK_Scedilla: int
XK_Tcaron: int
XK_Zacute: int
XK_Zcaron: int
XK_Zabovedot: int
XK_aogonek: int
XK_ogonek: int
XK_lstroke: int
XK_lcaron: int
XK_sacute: int
XK_caron: int
XK_scaron: int
XK_scedilla: int
XK_tcaron: int
XK_zacute: int
XK_doubleacute: int
XK_zcaron: int
XK_zabovedot: int
XK_Racute: int
XK_Abreve: int
XK_Lacute: int
XK_Cacute: int
XK_Ccaron: int
XK_Eogonek: int
XK_Ecaron: int
XK_Dcaron: int
XK_Dstroke: int
XK_Nacute: int
XK_Ncaron: int
XK_Odoubleacute: int
XK_Rcaron: int
XK_Uring: int
XK_Udoubleacute: int
XK_Tcedilla: int
XK_racute: int
XK_abreve: int
XK_lacute: int
XK_cacute: int
XK_ccaron: int
XK_eogonek: int
XK_ecaron: int
XK_dcaron: int
XK_dstroke: int
XK_nacute: int
XK_ncaron: int
XK_odoubleacute: int
XK_udoubleacute: int
XK_rcaron: int
XK_uring: int
XK_tcedilla: int
XK_abovedot: int
