XK_Hstroke: int
XK_Hcircumflex: int
XK_Iabovedot: int
XK_Gbreve: int
XK_Jcircumflex: int
XK_hstroke: int
XK_hcircumflex: int
XK_idotless: int
XK_gbreve: int
XK_jcircumflex: int
XK_Cabovedot: int
XK_Ccircumflex: int
XK_Gabovedot: int
XK_Gcircumflex: int
XK_Ubreve: int
XK_Scircumflex: int
XK_cabovedot: int
XK_ccircumflex: int
XK_gabovedot: int
XK_gcircumflex: int
XK_ubreve: int
XK_scircumflex: int
