NoValue: int
XValue: int
YValue: int
WidthValue: int
HeightValue: int
AllValues: int
XNegative: int
YNegative: int
USPosition: int
USSize: int
PPosition: int
PSize: int
PMinSize: int
PMaxSize: int
PResizeInc: int
PAspect: int
PBaseSize: int
PWinGravity: int
PAllHints: int
InputHint: int
StateHint: int
IconPixmapHint: int
IconWindowHint: int
IconPositionHint: int
IconMaskHint: int
WindowGroupHint: int
MessageHint: int
UrgencyHint: int
AllHints: int
WithdrawnState: int
NormalState: int
IconicState: int
DontCareState: int
ZoomState: int
InactiveState: int
RectangleOut: int
RectangleIn: int
RectanglePart: int
VisualNoMask: int
VisualIDMask: int
VisualScreenMask: int
VisualDepthMask: int
VisualClassMask: int
VisualRedMaskMask: int
VisualGreenMaskMask: int
VisualBlueMaskMask: int
VisualColormapSizeMask: int
VisualBitsPerRGBMask: int
VisualAllMask: int
ReleaseByFreeingColormap: int
BitmapSuccess: int
BitmapOpenFailed: int
BitmapFileInvalid: int
BitmapNoMemory: int
XCSUCCESS: int
XCNOMEM: int
XCNOENT: int
