NONE: int
ParentRelative: int
CopyFromParent: int
PointerWindow: int
InputFocus: int
PointerRoot: int
AnyPropertyType: int
AnyKey: int
AnyButton: int
AllTemporary: int
CurrentTime: int
NoSymbol: int
NoEventMask: int
KeyPressMask: int
KeyReleaseMask: int
ButtonPressMask: int
ButtonReleaseMask: int
EnterWindowMask: int
LeaveWindowMask: int
PointerMotionMask: int
PointerMotionHintMask: int
Button1MotionMask: int
Button2MotionMask: int
Button3MotionMask: int
Button4MotionMask: int
Button5MotionMask: int
ButtonMotionMask: int
KeymapStateMask: int
ExposureMask: int
VisibilityChangeMask: int
StructureNotifyMask: int
ResizeRedirectMask: int
SubstructureNotifyMask: int
SubstructureRedirectMask: int
FocusChangeMask: int
PropertyChangeMask: int
ColormapChangeMask: int
OwnerGrabButtonMask: int
KeyPress: int
KeyRelease: int
ButtonPress: int
ButtonRelease: int
MotionNotify: int
EnterNotify: int
LeaveNotify: int
FocusIn: int
FocusOut: int
KeymapNotify: int
Expose: int
GraphicsExpose: int
NoExpose: int
VisibilityNotify: int
CreateNotify: int
DestroyNotify: int
UnmapNotify: int
MapNotify: int
MapRequest: int
ReparentNotify: int
ConfigureNotify: int
ConfigureRequest: int
GravityNotify: int
ResizeRequest: int
CirculateNotify: int
CirculateRequest: int
PropertyNotify: int
SelectionClear: int
SelectionRequest: int
SelectionNotify: int
ColormapNotify: int
ClientMessage: int
MappingNotify: int
LASTEvent: int
ShiftMask: int
LockMask: int
ControlMask: int
Mod1Mask: int
Mod2Mask: int
Mod3Mask: int
Mod4Mask: int
Mod5Mask: int
ShiftMapIndex: int
LockMapIndex: int
ControlMapIndex: int
Mod1MapIndex: int
Mod2MapIndex: int
Mod3MapIndex: int
Mod4MapIndex: int
Mod5MapIndex: int
Button1Mask: int
Button2Mask: int
Button3Mask: int
Button4Mask: int
Button5Mask: int
AnyModifier: int
Button1: int
Button2: int
Button3: int
Button4: int
Button5: int
NotifyNormal: int
NotifyGrab: int
NotifyUngrab: int
NotifyWhileGrabbed: int
NotifyHint: int
NotifyAncestor: int
NotifyVirtual: int
NotifyInferior: int
NotifyNonlinear: int
NotifyNonlinearVirtual: int
NotifyPointer: int
NotifyPointerRoot: int
NotifyDetailNone: int
VisibilityUnobscured: int
VisibilityPartiallyObscured: int
VisibilityFullyObscured: int
PlaceOnTop: int
PlaceOnBottom: int
FamilyInternet: int
FamilyDECnet: int
FamilyChaos: int
FamilyServerInterpreted: int
FamilyInternetV6: int
PropertyNewValue: int
PropertyDelete: int
ColormapUninstalled: int
ColormapInstalled: int
GrabModeSync: int
GrabModeAsync: int
GrabSuccess: int
AlreadyGrabbed: int
GrabInvalidTime: int
GrabNotViewable: int
GrabFrozen: int
AsyncPointer: int
SyncPointer: int
ReplayPointer: int
AsyncKeyboard: int
SyncKeyboard: int
ReplayKeyboard: int
AsyncBoth: int
SyncBoth: int
RevertToNone: int
RevertToPointerRoot: int
RevertToParent: int
Success: int
BadRequest: int
BadValue: int
BadWindow: int
BadPixmap: int
BadAtom: int
BadCursor: int
BadFont: int
BadMatch: int
BadDrawable: int
BadAccess: int
BadAlloc: int
BadColor: int
BadGC: int
BadIDChoice: int
BadName: int
BadLength: int
BadImplementation: int
FirstExtensionError: int
LastExtensionError: int
InputOutput: int
InputOnly: int
CWBackPixmap: int
CWBackPixel: int
CWBorderPixmap: int
CWBorderPixel: int
CWBitGravity: int
CWWinGravity: int
CWBackingStore: int
CWBackingPlanes: int
CWBackingPixel: int
CWOverrideRedirect: int
CWSaveUnder: int
CWEventMask: int
CWDontPropagate: int
CWColormap: int
CWCursor: int
CWX: int
CWY: int
CWWidth: int
CWHeight: int
CWBorderWidth: int
CWSibling: int
CWStackMode: int
ForgetGravity: int
NorthWestGravity: int
NorthGravity: int
NorthEastGravity: int
WestGravity: int
CenterGravity: int
EastGravity: int
SouthWestGravity: int
SouthGravity: int
SouthEastGravity: int
StaticGravity: int
UnmapGravity: int
NotUseful: int
WhenMapped: int
Always: int
IsUnmapped: int
IsUnviewable: int
IsViewable: int
SetModeInsert: int
SetModeDelete: int
DestroyAll: int
RetainPermanent: int
RetainTemporary: int
Above: int
Below: int
TopIf: int
BottomIf: int
Opposite: int
RaiseLowest: int
LowerHighest: int
PropModeReplace: int
PropModePrepend: int
PropModeAppend: int
GXclear: int
GXand: int
GXandReverse: int
GXcopy: int
GXandInverted: int
GXnoop: int
GXxor: int
GXor: int
GXnor: int
GXequiv: int
GXinvert: int
GXorReverse: int
GXcopyInverted: int
GXorInverted: int
GXnand: int
GXset: int
LineSolid: int
LineOnOffDash: int
LineDoubleDash: int
CapNotLast: int
CapButt: int
CapRound: int
CapProjecting: int
JoinMiter: int
JoinRound: int
JoinBevel: int
FillSolid: int
FillTiled: int
FillStippled: int
FillOpaqueStippled: int
EvenOddRule: int
WindingRule: int
ClipByChildren: int
IncludeInferiors: int
Unsorted: int
YSorted: int
YXSorted: int
YXBanded: int
CoordModeOrigin: int
CoordModePrevious: int
Complex: int
Nonconvex: int
Convex: int
ArcChord: int
ArcPieSlice: int
GCFunction: int
GCPlaneMask: int
GCForeground: int
GCBackground: int
GCLineWidth: int
GCLineStyle: int
GCCapStyle: int
GCJoinStyle: int
GCFillStyle: int
GCFillRule: int
GCTile: int
GCStipple: int
GCTileStipXOrigin: int
GCTileStipYOrigin: int
GCFont: int
GCSubwindowMode: int
GCGraphicsExposures: int
GCClipXOrigin: int
GCClipYOrigin: int
GCClipMask: int
GCDashOffset: int
GCDashList: int
GCArcMode: int
GCLastBit: int
FontLeftToRight: int
FontRightToLeft: int
FontChange: int
XYBitmap: int
XYPixmap: int
ZPixmap: int
AllocNone: int
AllocAll: int
DoRed: int
DoGreen: int
DoBlue: int
CursorShape: int
TileShape: int
StippleShape: int
AutoRepeatModeOff: int
AutoRepeatModeOn: int
AutoRepeatModeDefault: int
LedModeOff: int
LedModeOn: int
KBKeyClickPercent: int
KBBellPercent: int
KBBellPitch: int
KBBellDuration: int
KBLed: int
KBLedMode: int
KBKey: int
KBAutoRepeatMode: int
MappingSuccess: int
MappingBusy: int
MappingFailed: int
MappingModifier: int
MappingKeyboard: int
MappingPointer: int
DontPreferBlanking: int
PreferBlanking: int
DefaultBlanking: int
DisableScreenSaver: int
DisableScreenInterval: int
DontAllowExposures: int
AllowExposures: int
DefaultExposures: int
ScreenSaverReset: int
ScreenSaverActive: int
HostInsert: int
HostDelete: int
EnableAccess: int
DisableAccess: int
StaticGray: int
GrayScale: int
StaticColor: int
PseudoColor: int
TrueColor: int
DirectColor: int
LSBFirst: int
MSBFirst: int
