XK_Thai_kokai: int
XK_Thai_khokhai: int
XK_Thai_khokhuat: int
XK_Thai_khokhwai: int
XK_Thai_khokhon: int
XK_Thai_khorakhang: int
XK_Thai_ngongu: int
XK_Thai_chochan: int
XK_Thai_choching: int
XK_Thai_chochang: int
XK_Thai_soso: int
XK_Thai_chochoe: int
XK_Thai_yoying: int
XK_Thai_dochada: int
XK_Thai_topatak: int
XK_Thai_thothan: int
XK_Thai_thonangmontho: int
XK_Thai_thophuthao: int
XK_Thai_nonen: int
XK_Thai_dodek: int
XK_Thai_totao: int
XK_Thai_thothung: int
XK_Thai_thothahan: int
XK_Thai_thothong: int
XK_Thai_nonu: int
XK_Thai_bobaimai: int
XK_Thai_popla: int
XK_Thai_phophung: int
XK_Thai_fofa: int
XK_Thai_phophan: int
XK_Thai_fofan: int
XK_Thai_phosamphao: int
XK_Thai_moma: int
XK_Thai_yoyak: int
XK_Thai_rorua: int
XK_Thai_ru: int
XK_Thai_loling: int
XK_Thai_lu: int
XK_Thai_wowaen: int
XK_Thai_sosala: int
XK_Thai_sorusi: int
XK_Thai_sosua: int
XK_Thai_hohip: int
XK_Thai_lochula: int
XK_Thai_oang: int
XK_Thai_honokhuk: int
XK_Thai_paiyannoi: int
XK_Thai_saraa: int
XK_Thai_maihanakat: int
XK_Thai_saraaa: int
XK_Thai_saraam: int
XK_Thai_sarai: int
XK_Thai_saraii: int
XK_Thai_saraue: int
XK_Thai_sarauee: int
XK_Thai_sarau: int
XK_Thai_sarauu: int
XK_Thai_phinthu: int
XK_Thai_maihanakat_maitho: int
XK_Thai_baht: int
XK_Thai_sarae: int
XK_Thai_saraae: int
XK_Thai_sarao: int
XK_Thai_saraaimaimuan: int
XK_Thai_saraaimaimalai: int
XK_Thai_lakkhangyao: int
XK_Thai_maiyamok: int
XK_Thai_maitaikhu: int
XK_Thai_maiek: int
XK_Thai_maitho: int
XK_Thai_maitri: int
XK_Thai_maichattawa: int
XK_Thai_thanthakhat: int
XK_Thai_nikhahit: int
XK_Thai_leksun: int
XK_Thai_leknung: int
XK_Thai_leksong: int
XK_Thai_leksam: int
XK_Thai_leksi: int
XK_Thai_lekha: int
XK_Thai_lekhok: int
XK_Thai_lekchet: int
XK_Thai_lekpaet: int
XK_Thai_lekkao: int
