num_glyphs: int
X_cursor: int
arrow: int
based_arrow_down: int
based_arrow_up: int
boat: int
bogosity: int
bottom_left_corner: int
bottom_right_corner: int
bottom_side: int
bottom_tee: int
box_spiral: int
center_ptr: int
circle: int
clock: int
coffee_mug: int
cross: int
cross_reverse: int
crosshair: int
diamond_cross: int
dot: int
dotbox: int
double_arrow: int
draft_large: int
draft_small: int
draped_box: int
exchange: int
fleur: int
gobbler: int
gumby: int
hand1: int
hand2: int
heart: int
icon: int
iron_cross: int
left_ptr: int
left_side: int
left_tee: int
leftbutton: int
ll_angle: int
lr_angle: int
man: int
middlebutton: int
mouse: int
pencil: int
pirate: int
plus: int
question_arrow: int
right_ptr: int
right_side: int
right_tee: int
rightbutton: int
rtl_logo: int
sailboat: int
sb_down_arrow: int
sb_h_double_arrow: int
sb_left_arrow: int
sb_right_arrow: int
sb_up_arrow: int
sb_v_double_arrow: int
shuttle: int
sizing: int
spider: int
spraycan: int
star: int
target: int
tcross: int
top_left_arrow: int
top_left_corner: int
top_right_corner: int
top_side: int
top_tee: int
trek: int
ul_angle: int
umbrella: int
ur_angle: int
watch: int
xterm: int
