XK_Serbian_dje: int
XK_Macedonia_gje: int
XK_Cyrillic_io: int
XK_Ukrainian_ie: int
XK_Ukranian_je: int
XK_Macedonia_dse: int
XK_Ukrainian_i: int
XK_Ukranian_i: int
XK_Ukrainian_yi: int
XK_Ukranian_yi: int
XK_Cyrillic_je: int
XK_Serbian_je: int
XK_Cyrillic_lje: int
XK_Serbian_lje: int
XK_Cyrillic_nje: int
XK_Serbian_nje: int
XK_Serbian_tshe: int
XK_Macedonia_kje: int
XK_Byelorussian_shortu: int
XK_Cyrillic_dzhe: int
XK_Serbian_dze: int
XK_numerosign: int
XK_Serbian_DJE: int
XK_Macedonia_GJE: int
XK_Cyrillic_IO: int
XK_Ukrainian_IE: int
XK_Ukranian_JE: int
XK_Macedonia_DSE: int
XK_Ukrainian_I: int
XK_Ukranian_I: int
XK_Ukrainian_YI: int
XK_Ukranian_YI: int
XK_Cyrillic_JE: int
XK_Serbian_JE: int
XK_Cyrillic_LJE: int
XK_Serbian_LJE: int
XK_Cyrillic_NJE: int
XK_Serbian_NJE: int
XK_Serbian_TSHE: int
XK_Macedonia_KJE: int
XK_Byelorussian_SHORTU: int
XK_Cyrillic_DZHE: int
XK_Serbian_DZE: int
XK_Cyrillic_yu: int
XK_Cyrillic_a: int
XK_Cyrillic_be: int
XK_Cyrillic_tse: int
XK_Cyrillic_de: int
XK_Cyrillic_ie: int
XK_Cyrillic_ef: int
XK_Cyrillic_ghe: int
XK_Cyrillic_ha: int
XK_Cyrillic_i: int
XK_Cyrillic_shorti: int
XK_Cyrillic_ka: int
XK_Cyrillic_el: int
XK_Cyrillic_em: int
XK_Cyrillic_en: int
XK_Cyrillic_o: int
XK_Cyrillic_pe: int
XK_Cyrillic_ya: int
XK_Cyrillic_er: int
XK_Cyrillic_es: int
XK_Cyrillic_te: int
XK_Cyrillic_u: int
XK_Cyrillic_zhe: int
XK_Cyrillic_ve: int
XK_Cyrillic_softsign: int
XK_Cyrillic_yeru: int
XK_Cyrillic_ze: int
XK_Cyrillic_sha: int
XK_Cyrillic_e: int
XK_Cyrillic_shcha: int
XK_Cyrillic_che: int
XK_Cyrillic_hardsign: int
XK_Cyrillic_YU: int
XK_Cyrillic_A: int
XK_Cyrillic_BE: int
XK_Cyrillic_TSE: int
XK_Cyrillic_DE: int
XK_Cyrillic_IE: int
XK_Cyrillic_EF: int
XK_Cyrillic_GHE: int
XK_Cyrillic_HA: int
XK_Cyrillic_I: int
XK_Cyrillic_SHORTI: int
XK_Cyrillic_KA: int
XK_Cyrillic_EL: int
XK_Cyrillic_EM: int
XK_Cyrillic_EN: int
XK_Cyrillic_O: int
XK_Cyrillic_PE: int
XK_Cyrillic_YA: int
XK_Cyrillic_ER: int
XK_Cyrillic_ES: int
XK_Cyrillic_TE: int
XK_Cyrillic_U: int
XK_Cyrillic_ZHE: int
XK_Cyrillic_VE: int
XK_Cyrillic_SOFTSIGN: int
XK_Cyrillic_YERU: int
XK_Cyrillic_ZE: int
XK_Cyrillic_SHA: int
XK_Cyrillic_E: int
XK_Cyrillic_SHCHA: int
XK_Cyrillic_CHE: int
XK_Cyrillic_HARDSIGN: int
