XK_emspace: int
XK_enspace: int
XK_em3space: int
XK_em4space: int
XK_digitspace: int
XK_punctspace: int
XK_thinspace: int
XK_hairspace: int
XK_emdash: int
XK_endash: int
XK_signifblank: int
XK_ellipsis: int
XK_doubbaselinedot: int
XK_onethird: int
XK_twothirds: int
XK_onefifth: int
XK_twofifths: int
XK_threefifths: int
XK_fourfifths: int
XK_onesixth: int
XK_fivesixths: int
XK_careof: int
XK_figdash: int
XK_leftanglebracket: int
XK_decimalpoint: int
XK_rightanglebracket: int
XK_marker: int
XK_oneeighth: int
XK_threeeighths: int
XK_fiveeighths: int
XK_seveneighths: int
XK_trademark: int
XK_signaturemark: int
XK_trademarkincircle: int
XK_leftopentriangle: int
XK_rightopentriangle: int
XK_emopencircle: int
XK_emopenrectangle: int
XK_leftsinglequotemark: int
XK_rightsinglequotemark: int
XK_leftdoublequotemark: int
XK_rightdoublequotemark: int
XK_prescription: int
XK_minutes: int
XK_seconds: int
XK_latincross: int
XK_hexagram: int
XK_filledrectbullet: int
XK_filledlefttribullet: int
XK_filledrighttribullet: int
XK_emfilledcircle: int
XK_emfilledrect: int
XK_enopencircbullet: int
XK_enopensquarebullet: int
XK_openrectbullet: int
XK_opentribulletup: int
XK_opentribulletdown: int
XK_openstar: int
XK_enfilledcircbullet: int
XK_enfilledsqbullet: int
XK_filledtribulletup: int
XK_filledtribulletdown: int
XK_leftpointer: int
XK_rightpointer: int
XK_club: int
XK_diamond: int
XK_heart: int
XK_maltesecross: int
XK_dagger: int
XK_doubledagger: int
XK_checkmark: int
XK_ballotcross: int
XK_musicalsharp: int
XK_musicalflat: int
XK_malesymbol: int
XK_femalesymbol: int
XK_telephone: int
XK_telephonerecorder: int
XK_phonographcopyright: int
XK_caret: int
XK_singlelowquotemark: int
XK_doublelowquotemark: int
XK_cursor: int
