PRIMARY: int
SECONDARY: int
ARC: int
ATOM: int
BITMAP: int
CARDINAL: int
COLORMAP: int
CURSOR: int
CUT_BUFFER0: int
CUT_BUFFER1: int
CUT_BUFFER2: int
CUT_BUFFER3: int
CUT_BUFFER4: int
CUT_BUFFER5: int
CUT_BUFFER6: int
CUT_BUFFER7: int
DRAWABLE: int
FONT: int
INTEGER: int
PIXMAP: int
POINT: int
RECTANGLE: int
RESOURCE_MANAGER: int
RGB_COLOR_MAP: int
RGB_BEST_MAP: int
RGB_BLUE_MAP: int
RGB_DEFAULT_MAP: int
RGB_GRAY_MAP: int
RGB_GREEN_MAP: int
RGB_RED_MAP: int
STRING: int
VISUALID: int
WINDOW: int
WM_COMMAND: int
WM_HINTS: int
WM_CLIENT_MACHINE: int
WM_ICON_NAME: int
WM_ICON_SIZE: int
WM_NAME: int
WM_NORMAL_HINTS: int
WM_SIZE_HINTS: int
WM_ZOOM_HINTS: int
MIN_SPACE: int
NORM_SPACE: int
MAX_SPACE: int
END_SPACE: int
SUPERSCRIPT_X: int
SUPERSCRIPT_Y: int
SUBSCRIPT_X: int
SUBSCRIPT_Y: int
UNDERLINE_POSITION: int
UNDERLINE_THICKNESS: int
STRIKEOUT_ASCENT: int
STRIKEOUT_DESCENT: int
ITALIC_ANGLE: int
X_HEIGHT: int
QUAD_WIDTH: int
WEIGHT: int
POINT_SIZE: int
RESOLUTION: int
COPYRIGHT: int
NOTICE: int
FONT_NAME: int
FAMILY_NAME: int
FULL_NAME: int
CAP_HEIGHT: int
WM_CLASS: int
WM_TRANSIENT_FOR: int
LAST_PREDEFINED: int
