XK_leftradical: int
XK_topleftradical: int
XK_horizconnector: int
XK_topintegral: int
XK_botintegral: int
XK_vertconnector: int
XK_topleftsqbracket: int
XK_botleftsqbracket: int
XK_toprightsqbracket: int
XK_botrightsqbracket: int
XK_topleftparens: int
XK_botleftparens: int
XK_toprightparens: int
XK_botrightparens: int
XK_leftmiddlecurlybrace: int
XK_rightmiddlecurlybrace: int
XK_topleftsummation: int
XK_botleftsummation: int
XK_topvertsummationconnector: int
XK_botvertsummationconnector: int
XK_toprightsummation: int
XK_botrightsummation: int
XK_rightmiddlesummation: int
XK_lessthanequal: int
XK_notequal: int
XK_greaterthanequal: int
XK_integral: int
XK_therefore: int
XK_variation: int
XK_infinity: int
XK_nabla: int
XK_approximate: int
XK_similarequal: int
XK_ifonlyif: int
XK_implies: int
XK_identical: int
XK_radical: int
XK_includedin: int
XK_includes: int
XK_intersection: int
XK_union: int
XK_logicaland: int
XK_logicalor: int
XK_partialderivative: int
XK_function: int
XK_leftarrow: int
XK_uparrow: int
XK_rightarrow: int
XK_downarrow: int
