XK_blank: int
XK_soliddiamond: int
XK_checkerboard: int
XK_ht: int
XK_ff: int
XK_cr: int
XK_lf: int
XK_nl: int
XK_vt: int
XK_lowrightcorner: int
XK_uprightcorner: int
XK_upleftcorner: int
XK_lowleftcorner: int
XK_crossinglines: int
XK_horizlinescan1: int
XK_horizlinescan3: int
XK_horizlinescan5: int
XK_horizlinescan7: int
XK_horizlinescan9: int
XK_leftt: int
XK_rightt: int
XK_bott: int
XK_topt: int
XK_vertbar: int
