XK_leftcaret: int
XK_rightcaret: int
XK_downcaret: int
XK_upcaret: int
XK_overbar: int
XK_downtack: int
XK_upshoe: int
XK_downstile: int
XK_underbar: int
XK_jot: int
XK_quad: int
XK_uptack: int
XK_circle: int
XK_upstile: int
XK_downshoe: int
XK_rightshoe: int
XK_leftshoe: int
XK_lefttack: int
XK_righttack: int
