XK_kra: int
XK_kappa: int
XK_Rcedilla: int
XK_Itilde: int
XK_Lcedilla: int
XK_Emacron: int
XK_Gcedilla: int
XK_Tslash: int
XK_rcedilla: int
XK_itilde: int
XK_lcedilla: int
XK_emacron: int
XK_gcedilla: int
XK_tslash: int
XK_ENG: int
XK_eng: int
XK_Amacron: int
XK_Iogonek: int
XK_Eabovedot: int
XK_Imacron: int
XK_Ncedilla: int
XK_Omacron: int
XK_Kcedilla: int
XK_Uogonek: int
XK_Utilde: int
XK_Umacron: int
XK_amacron: int
XK_iogonek: int
XK_eabovedot: int
XK_imacron: int
XK_ncedilla: int
XK_omacron: int
XK_kcedilla: int
XK_uogonek: int
XK_utilde: int
XK_umacron: int
