XK_3270_Duplicate: int
XK_3270_FieldMark: int
XK_3270_Right2: int
XK_3270_Left2: int
XK_3270_BackTab: int
XK_3270_EraseEOF: int
XK_3270_EraseInput: int
XK_3270_Reset: int
XK_3270_Quit: int
XK_3270_PA1: int
XK_3270_PA2: int
XK_3270_PA3: int
XK_3270_Test: int
XK_3270_Attn: int
XK_3270_CursorBlink: int
XK_3270_AltCursor: int
XK_3270_KeyClick: int
XK_3270_Jump: int
XK_3270_Ident: int
XK_3270_Rule: int
XK_3270_Copy: int
XK_3270_Play: int
XK_3270_Setup: int
XK_3270_Record: int
XK_3270_ChangeScreen: int
XK_3270_DeleteWord: int
XK_3270_ExSelect: int
XK_3270_CursorSelect: int
XK_3270_PrintScreen: int
XK_3270_Enter: int
