XK_XF86_ModeLock: int
XK_XF86_MonBrightnessUp: int
XK_XF86_MonBrightnessDown: int
XK_XF86_KbdLightOnOff: int
XK_XF86_KbdBrightnessUp: int
XK_XF86_KbdBrightnessDown: int
XK_XF86_MonBrightnessCycle: int
XK_XF86_Standby: int
XK_XF86_AudioLowerVolume: int
XK_XF86_AudioMute: int
XK_XF86_AudioRaiseVolume: int
XK_XF86_AudioPlay: int
XK_XF86_AudioStop: int
XK_XF86_AudioPrev: int
XK_XF86_AudioNext: int
XK_XF86_HomePage: int
XK_XF86_Mail: int
XK_XF86_Start: int
XK_XF86_Search: int
XK_XF86_AudioRecord: int
XK_XF86_Calculator: int
XK_XF86_Memo: int
XK_XF86_ToDoList: int
XK_XF86_Calendar: int
XK_XF86_PowerDown: int
XK_XF86_ContrastAdjust: int
XK_XF86_RockerUp: int
XK_XF86_RockerDown: int
XK_XF86_RockerEnter: int
XK_XF86_Back: int
XK_XF86_Forward: int
XK_XF86_Stop: int
XK_XF86_Refresh: int
XK_XF86_PowerOff: int
XK_XF86_WakeUp: int
XK_XF86_Eject: int
XK_XF86_ScreenSaver: int
XK_XF86_WWW: int
XK_XF86_Sleep: int
XK_XF86_Favorites: int
XK_XF86_AudioPause: int
XK_XF86_AudioMedia: int
XK_XF86_MyComputer: int
XK_XF86_VendorHome: int
XK_XF86_LightBulb: int
XK_XF86_Shop: int
XK_XF86_History: int
XK_XF86_OpenURL: int
XK_XF86_AddFavorite: int
XK_XF86_HotLinks: int
XK_XF86_BrightnessAdjust: int
XK_XF86_Finance: int
XK_XF86_Community: int
XK_XF86_AudioRewind: int
XK_XF86_XF86BackForward: int
XK_XF86_Launch0: int
XK_XF86_Launch1: int
XK_XF86_Launch2: int
XK_XF86_Launch3: int
XK_XF86_Launch4: int
XK_XF86_Launch5: int
XK_XF86_Launch6: int
XK_XF86_Launch7: int
XK_XF86_Launch8: int
XK_XF86_Launch9: int
XK_XF86_LaunchA: int
XK_XF86_LaunchB: int
XK_XF86_LaunchC: int
XK_XF86_LaunchD: int
XK_XF86_LaunchE: int
XK_XF86_LaunchF: int
XK_XF86_ApplicationLeft: int
XK_XF86_ApplicationRight: int
XK_XF86_Book: int
XK_XF86_CD: int
XK_XF86_Calculater: int
XK_XF86_Clear: int
XK_XF86_Close: int
XK_XF86_Copy: int
XK_XF86_Cut: int
XK_XF86_Display: int
XK_XF86_DOS: int
XK_XF86_Documents: int
XK_XF86_Excel: int
XK_XF86_Explorer: int
XK_XF86_Game: int
XK_XF86_Go: int
XK_XF86_iTouch: int
XK_XF86_LogOff: int
XK_XF86_Market: int
XK_XF86_Meeting: int
XK_XF86_MenuKB: int
XK_XF86_MenuPB: int
XK_XF86_MySites: int
XK_XF86_New: int
XK_XF86_News: int
XK_XF86_OfficeHome: int
XK_XF86_Open: int
XK_XF86_Option: int
XK_XF86_Paste: int
XK_XF86_Phone: int
XK_XF86_Q: int
XK_XF86_Reply: int
XK_XF86_Reload: int
XK_XF86_RotateWindows: int
XK_XF86_RotationPB: int
XK_XF86_RotationKB: int
XK_XF86_Save: int
XK_XF86_ScrollUp: int
XK_XF86_ScrollDown: int
XK_XF86_ScrollClick: int
XK_XF86_Send: int
XK_XF86_Spell: int
XK_XF86_SplitScreen: int
XK_XF86_Support: int
XK_XF86_TaskPane: int
XK_XF86_Terminal: int
XK_XF86_Tools: int
XK_XF86_Travel: int
XK_XF86_UserPB: int
XK_XF86_User1KB: int
XK_XF86_User2KB: int
XK_XF86_Video: int
XK_XF86_WheelButton: int
XK_XF86_Word: int
XK_XF86_Xfer: int
XK_XF86_ZoomIn: int
XK_XF86_ZoomOut: int
XK_XF86_Away: int
XK_XF86_Messenger: int
XK_XF86_WebCam: int
XK_XF86_MailForward: int
XK_XF86_Pictures: int
XK_XF86_Music: int
XK_XF86_Battery: int
XK_XF86_Bluetooth: int
XK_XF86_WLAN: int
XK_XF86_UWB: int
XK_XF86_AudioForward: int
XK_XF86_AudioRepeat: int
XK_XF86_AudioRandomPlay: int
XK_XF86_Subtitle: int
XK_XF86_AudioCycleTrack: int
XK_XF86_CycleAngle: int
XK_XF86_FrameBack: int
XK_XF86_FrameForward: int
XK_XF86_Time: int
XK_XF86_Select: int
XK_XF86_View: int
XK_XF86_TopMenu: int
XK_XF86_Red: int
XK_XF86_Green: int
XK_XF86_Yellow: int
XK_XF86_Blue: int
XK_XF86_Suspend: int
XK_XF86_Hibernate: int
XK_XF86_TouchpadToggle: int
XK_XF86_TouchpadOn: int
XK_XF86_TouchpadOff: int
XK_XF86_AudioMicMute: int
XK_XF86_Keyboard: int
XK_XF86_WWAN: int
XK_XF86_RFKill: int
XK_XF86_AudioPreset: int
XK_XF86_RotationLockToggle: int
XK_XF86_FullScreen: int
XK_XF86_Switch_VT_1: int
XK_XF86_Switch_VT_2: int
XK_XF86_Switch_VT_3: int
XK_XF86_Switch_VT_4: int
XK_XF86_Switch_VT_5: int
XK_XF86_Switch_VT_6: int
XK_XF86_Switch_VT_7: int
XK_XF86_Switch_VT_8: int
XK_XF86_Switch_VT_9: int
XK_XF86_Switch_VT_10: int
XK_XF86_Switch_VT_11: int
XK_XF86_Switch_VT_12: int
XK_XF86_Ungrab: int
XK_XF86_ClearGrab: int
XK_XF86_Next_VMode: int
XK_XF86_Prev_VMode: int
XK_XF86_LogWindowTree: int
XK_XF86_LogGrabInfo: int
