XK_hebrew_doublelowline: int
XK_hebrew_aleph: int
XK_hebrew_bet: int
XK_hebrew_beth: int
XK_hebrew_gimel: int
XK_hebrew_gimmel: int
XK_hebrew_dalet: int
XK_hebrew_daleth: int
XK_hebrew_he: int
XK_hebrew_waw: int
XK_hebrew_zain: int
XK_hebrew_zayin: int
XK_hebrew_chet: int
XK_hebrew_het: int
XK_hebrew_tet: int
XK_hebrew_teth: int
XK_hebrew_yod: int
XK_hebrew_finalkaph: int
XK_hebrew_kaph: int
XK_hebrew_lamed: int
XK_hebrew_finalmem: int
XK_hebrew_mem: int
XK_hebrew_finalnun: int
XK_hebrew_nun: int
XK_hebrew_samech: int
XK_hebrew_samekh: int
XK_hebrew_ayin: int
XK_hebrew_finalpe: int
XK_hebrew_pe: int
XK_hebrew_finalzade: int
XK_hebrew_finalzadi: int
XK_hebrew_zade: int
XK_hebrew_zadi: int
XK_hebrew_qoph: int
XK_hebrew_kuf: int
XK_hebrew_resh: int
XK_hebrew_shin: int
XK_hebrew_taw: int
XK_hebrew_taf: int
XK_Hebrew_switch: int
