XK_space: int
XK_exclam: int
XK_quotedbl: int
XK_numbersign: int
XK_dollar: int
XK_percent: int
XK_ampersand: int
XK_apostrophe: int
XK_quoteright: int
XK_parenleft: int
XK_parenright: int
XK_asterisk: int
XK_plus: int
XK_comma: int
XK_minus: int
XK_period: int
XK_slash: int
XK_0: int
XK_1: int
XK_2: int
XK_3: int
XK_4: int
XK_5: int
XK_6: int
XK_7: int
XK_8: int
XK_9: int
XK_colon: int
XK_semicolon: int
XK_less: int
XK_equal: int
XK_greater: int
XK_question: int
XK_at: int
XK_A: int
XK_B: int
XK_C: int
XK_D: int
XK_E: int
XK_F: int
XK_G: int
XK_H: int
XK_I: int
XK_J: int
XK_K: int
XK_L: int
XK_M: int
XK_N: int
XK_O: int
XK_P: int
XK_Q: int
XK_R: int
XK_S: int
XK_T: int
XK_U: int
XK_V: int
XK_W: int
XK_X: int
XK_Y: int
XK_Z: int
XK_bracketleft: int
XK_backslash: int
XK_bracketright: int
XK_asciicircum: int
XK_underscore: int
XK_grave: int
XK_quoteleft: int
XK_a: int
XK_b: int
XK_c: int
XK_d: int
XK_e: int
XK_f: int
XK_g: int
XK_h: int
XK_i: int
XK_j: int
XK_k: int
XK_l: int
XK_m: int
XK_n: int
XK_o: int
XK_p: int
XK_q: int
XK_r: int
XK_s: int
XK_t: int
XK_u: int
XK_v: int
XK_w: int
XK_x: int
XK_y: int
XK_z: int
XK_braceleft: int
XK_bar: int
XK_braceright: int
XK_asciitilde: int
XK_nobreakspace: int
XK_exclamdown: int
XK_cent: int
XK_sterling: int
XK_currency: int
XK_yen: int
XK_brokenbar: int
XK_section: int
XK_diaeresis: int
XK_copyright: int
XK_ordfeminine: int
XK_guillemotleft: int
XK_notsign: int
XK_hyphen: int
XK_registered: int
XK_macron: int
XK_degree: int
XK_plusminus: int
XK_twosuperior: int
XK_threesuperior: int
XK_acute: int
XK_mu: int
XK_paragraph: int
XK_periodcentered: int
XK_cedilla: int
XK_onesuperior: int
XK_masculine: int
XK_guillemotright: int
XK_onequarter: int
XK_onehalf: int
XK_threequarters: int
XK_questiondown: int
XK_Agrave: int
XK_Aacute: int
XK_Acircumflex: int
XK_Atilde: int
XK_Adiaeresis: int
XK_Aring: int
XK_AE: int
XK_Ccedilla: int
XK_Egrave: int
XK_Eacute: int
XK_Ecircumflex: int
XK_Ediaeresis: int
XK_Igrave: int
XK_Iacute: int
XK_Icircumflex: int
XK_Idiaeresis: int
XK_ETH: int
XK_Eth: int
XK_Ntilde: int
XK_Ograve: int
XK_Oacute: int
XK_Ocircumflex: int
XK_Otilde: int
XK_Odiaeresis: int
XK_multiply: int
XK_Ooblique: int
XK_Ugrave: int
XK_Uacute: int
XK_Ucircumflex: int
XK_Udiaeresis: int
XK_Yacute: int
XK_THORN: int
XK_Thorn: int
XK_ssharp: int
XK_agrave: int
XK_aacute: int
XK_acircumflex: int
XK_atilde: int
XK_adiaeresis: int
XK_aring: int
XK_ae: int
XK_ccedilla: int
XK_egrave: int
XK_eacute: int
XK_ecircumflex: int
XK_ediaeresis: int
XK_igrave: int
XK_iacute: int
XK_icircumflex: int
XK_idiaeresis: int
XK_eth: int
XK_ntilde: int
XK_ograve: int
XK_oacute: int
XK_ocircumflex: int
XK_otilde: int
XK_odiaeresis: int
XK_division: int
XK_oslash: int
XK_ugrave: int
XK_uacute: int
XK_ucircumflex: int
XK_udiaeresis: int
XK_yacute: int
XK_thorn: int
XK_ydiaeresis: int
