XK_Arabic_comma: int
XK_Arabic_semicolon: int
XK_Arabic_question_mark: int
XK_Arabic_hamza: int
XK_Arabic_maddaonalef: int
XK_Arabic_hamzaonalef: int
XK_Arabic_hamzaonwaw: int
XK_Arabic_hamzaunderalef: int
XK_Arabic_hamzaonyeh: int
XK_Arabic_alef: int
XK_Arabic_beh: int
XK_Arabic_tehmarbuta: int
XK_Arabic_teh: int
XK_Arabic_theh: int
XK_Arabic_jeem: int
XK_Arabic_hah: int
XK_Arabic_khah: int
XK_Arabic_dal: int
XK_Arabic_thal: int
XK_Arabic_ra: int
XK_Arabic_zain: int
XK_Arabic_seen: int
XK_Arabic_sheen: int
XK_Arabic_sad: int
XK_Arabic_dad: int
XK_Arabic_tah: int
XK_Arabic_zah: int
XK_Arabic_ain: int
XK_Arabic_ghain: int
XK_Arabic_tatweel: int
XK_Arabic_feh: int
XK_Arabic_qaf: int
XK_Arabic_kaf: int
XK_Arabic_lam: int
XK_Arabic_meem: int
XK_Arabic_noon: int
XK_Arabic_ha: int
XK_Arabic_heh: int
XK_Arabic_waw: int
XK_Arabic_alefmaksura: int
XK_Arabic_yeh: int
XK_Arabic_fathatan: int
XK_Arabic_dammatan: int
XK_Arabic_kasratan: int
XK_Arabic_fatha: int
XK_Arabic_damma: int
XK_Arabic_kasra: int
XK_Arabic_shadda: int
XK_Arabic_sukun: int
XK_Arabic_switch: int
